@@ -74,17 +74,18 @@ func (r *runner) Get(w io.Writer, subCmdArgs []string) (help.HelpMessage, error)
 		logger = nil
 	}
 	for _, a := range flags.Args() {
-		err = context.Get(logger, a, *insecure)
+		pkg, err := context.Get(logger, a, *insecure)
 		if err != nil {
 			return help.MsgNone, err
 		}
-		r.GoCmd("install", []string{a})
+
+		r.GoCmd("install", []string{pkg.Path})
 	}
 	return help.MsgNone, nil
 }
 
 func (r *runner) GoCmd(subcmd string, args []string) (help.HelpMessage, error) {
-	ctx, err := r.NewContextWD(context.RootVendorOrWD)
+	ctx, err := r.NewContextWD(context.RootVendorOrWDOrFirstGOPATH)
 	if err != nil {
 		return help.MsgNone, err
 	}
@@ -151,5 +152,5 @@ func (r *runner) Status(w io.Writer, subCmdArgs []string) (help.HelpMessage, err
 	for _, pkg := range outOfDate {
 		fmt.Fprintf(w, "\t%s\n", pkg.Path)
 	}
-	return help.MsgNone, nil
+	return help.MsgNone, fmt.Errorf("status failed for %d package(s)", len(outOfDate))
 }
